==> estateplat-common-1.2.4-20200825.013203-413-sources.jar: cn/gtmap/estateplat/model/server/core/BdcBdcdy.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * 不动产单元
 *
 * @author <a href="mailto:shenjian@gtmap.cn">jane</a>
 * @version 1.0, 2015/11/1
 */
@Table(name = "bdc_bdcdy")
public class BdcBdcdy implements Serializable, InsertVo {
    @Id
    private String bdcdyid;//不动产单元id
    private String bdcdyh;//不动产单元号

    private String djbid;//登记薄id

    private String bdclx;//不动产类型

    private String bdcdyfwlx;//权籍系统字典项
    private String ybdcdyh;//如果来源于房产登记，则记录房屋编号，如果来源余土地登记，则记录地籍号。存在多个时以逗号隔开
    private String bz;
    //原地籍号
    private String ydjh;

    private  String fwbm;//房屋编码


    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getBdcdyid() {
        return bdcdyid;
    }

    public void setBdcdyid(String bdcdyid) {
        this.bdcdyid = bdcdyid;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getDjbid() {
        return djbid;
    }

    public void setDjbid(String djbid) {
        this.djbid = djbid;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public String getBdcdyfwlx() {
        return bdcdyfwlx;
    }

    public void setBdcdyfwlx(String bdcdyfwlx) {
        this.bdcdyfwlx = bdcdyfwlx;
    }

    public String getYbdcdyh() {
        return ybdcdyh;
    }

    public void setYbdcdyh(String ybdcdyh) {
        this.ybdcdyh = ybdcdyh;
    }

	@Override
	public boolean equals(Object o) {
		if (this == o) return true;
		if (o == null || getClass() != o.getClass()) return false;

		BdcBdcdy bdcBdcdy = (BdcBdcdy) o;

		if (bdcdyid != null ? !bdcdyid.equals(bdcBdcdy.bdcdyid) : bdcBdcdy.bdcdyid != null) return false;

		return true;
	}

	@Override
	public int hashCode() {
		return bdcdyid != null ? bdcdyid.hashCode() : 0;
	}

    public String getYdjh() {
        return ydjh;
    }

    public void setYdjh(String ydjh) {
        this.ydjh = ydjh;
    }

    public String getFwbm() {
        return fwbm;
    }

    public void setFwbm(String fwbm) {
        this.fwbm = fwbm;
    }
}

==> estateplat-common-1.2.4-20230613.061541-1179-sources.jar: cn/gtmap/estateplat/model/server/core/BdcBdcdy.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * 不动产单元
 *
 * @author <a href="mailto:shenjian@gtmap.cn">jane</a>
 * @version 1.0, 2015/11/1
 */
@Table(name = "bdc_bdcdy")
public class BdcBdcdy implements Serializable, InsertVo {
    @Id
    private String bdcdyid;//不动产单元id
    private String bdcdyh;//不动产单元号

    private String djbid;//登记薄id

    private String bdclx;//不动产类型

    private String bdcdyfwlx;//权籍系统字典项
    private String ybdcdyh;//如果来源于房产登记，则记录房屋编号，如果来源余土地登记，则记录地籍号。存在多个时以逗号隔开
    private String bz;
    //原地籍号
    private String ydjh;

    private  String fwbm;//房屋编码

    private  String zyzt;//占用状态


    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getBdcdyid() {
        return bdcdyid;
    }

    public void setBdcdyid(String bdcdyid) {
        this.bdcdyid = bdcdyid;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getDjbid() {
        return djbid;
    }

    public void setDjbid(String djbid) {
        this.djbid = djbid;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public String getBdcdyfwlx() {
        return bdcdyfwlx;
    }

    public void setBdcdyfwlx(String bdcdyfwlx) {
        this.bdcdyfwlx = bdcdyfwlx;
    }

    public String getYbdcdyh() {
        return ybdcdyh;
    }

    public void setYbdcdyh(String ybdcdyh) {
        this.ybdcdyh = ybdcdyh;
    }

	@Override
	public boolean equals(Object o) {
		if (this == o) return true;
		if (o == null || getClass() != o.getClass()) return false;

		BdcBdcdy bdcBdcdy = (BdcBdcdy) o;

		if (bdcdyid != null ? !bdcdyid.equals(bdcBdcdy.bdcdyid) : bdcBdcdy.bdcdyid != null) return false;

		return true;
	}

	@Override
	public int hashCode() {
		return bdcdyid != null ? bdcdyid.hashCode() : 0;
	}

    public String getYdjh() {
        return ydjh;
    }

    public void setYdjh(String ydjh) {
        this.ydjh = ydjh;
    }

    public String getFwbm() {
        return fwbm;
    }

    public void setFwbm(String fwbm) {
        this.fwbm = fwbm;
    }

    public String getZyzt() {
        return zyzt;
    }

    public void setZyzt(String zyzt) {
        this.zyzt = zyzt;
    }
}
